# coding: utf-8

"""
    Nuon

    API for managing nuon apps, components, and installs.

    The version of the OpenAPI document: 0.19.106
    Contact: support@nuon.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from nuon.models.app_org_invite_status import AppOrgInviteStatus

class TestAppOrgInviteStatus(unittest.TestCase):
    """AppOrgInviteStatus unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testAppOrgInviteStatus(self):
        """Test AppOrgInviteStatus"""
        # inst = AppOrgInviteStatus()

if __name__ == '__main__':
    unittest.main()
